@@ -4,9 +4,15 @@ class Struct:
             # copy constructor
             for field in self._fields:
                 setattr(self, field[0], getattr(args[0], field[0]))
+        elif len(args) == len(self._fields):
+            for field, value in zip(self._fields, args):
+                setattr(self, field[0], field[1](value))
+        elif not args:
+            for field in self._fields:
+                setattr(self, field[0], None)
 
     def serialize(self):
-        r = b''
+        r = b""
         for field in self._fields:
             r += getattr(self, field[0]).serialize()
         return r
@@ -20,9 +26,9 @@ class Struct:
         return r, data
 
     def __repr__(self):
-        r = '<%s ' % (self.__class__.__name__, )
-        r += ' '.join(
-            ['%s=%s' % (f[0], getattr(self, f[0], None)) for f in self._fields]
+        r = "<%s " % (self.__class__.__name__,)
+        r += " ".join(
+            ["%s=%s" % (f[0], getattr(self, f[0], None)) for f in self._fields]
         )
-        r += '>'
+        r += ">"
         return r
